.. psyrun documentation master file, created by
   sphinx-quickstart on Wed Jul 15 12:42:10 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Psyrun: parameter space exploration and serial farming
======================================================

Psyrun is a `Python <https://www.python.org>`_ tool to define parameter spaces
and execute an evaluation function for each parameter assignment. In addition,
Psyrun makes it easy to use serial farming, i.e. evaluating multiple parameter
assignments in parallel, on a multicore computers and high-performance clusters.

Contents
--------

.. toctree::
   :maxdepth: 2

   installation
   tutorial
   guide
   api


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

